==> touhoulittlemaid-fabric-1.21.1-0.0.2-neo1.2.2-sources.jar: com/github/tartaricacid/touhoulittlemaid/client/renderer/tileentity/PicnicBasketRender.java <==
package com.github.tartaricacid.touhoulittlemaid.client.renderer.tileentity;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.client.model.EntityPlaceholderModel;
import com.github.tartaricacid.touhoulittlemaid.client.model.PicnicBasketModel;
import net.minecraft.class_1799;
import net.minecraft.class_1921;
import net.minecraft.class_2960;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_5599;
import net.minecraft.class_756;
import net.minecraft.class_7833;
import net.minecraft.class_811;
import net.minecraft.class_824;

public class PicnicBasketRender extends class_756 {
    private static final class_2960 TEXTURE = class_2960.method_60655(TouhouLittleMaid.MOD_ID, "textures/entity/picnic_basket.png");
    private static final class_2960 GUI_TEXTURE = class_2960.method_60655(TouhouLittleMaid.MOD_ID, "textures/item/picnic_basket.png");
    private static final EntityPlaceholderModel GUI_MODEL = new EntityPlaceholderModel();
    private final PicnicBasketModel model;

    public PicnicBasketRender(class_824 dispatcher, class_5599 modelSet) {
        super(dispatcher, modelSet);
        this.model = new PicnicBasketModel(modelSet.method_32072(PicnicBasketModel.LAYER));
    }

    @Override
    public void method_3166(class_1799 pStack, class_811 displayContext, class_4587 poseStack, class_4597 buffer, int packedLight, int packedOverlay) {
        if (displayContext == class_811.field_4317) {
            poseStack.method_22903();
            poseStack.method_22904(0.5, 1.5, 0.5);
            poseStack.method_22907(class_7833.field_40717.rotationDegrees(180));
            GUI_MODEL.renderToBuffer(poseStack, buffer.getBuffer(class_1921.method_23578(GUI_TEXTURE)), packedLight, packedOverlay, 1.0F, 1.0F, 1.0F, 1.0F);
            poseStack.method_22909();
        } else {
            poseStack.method_22903();
            poseStack.method_22904(0.5, 1.5, 0.5);
            poseStack.method_22907(class_7833.field_40717.rotationDegrees(180));
            class_1921 renderType = class_1921.method_23578(TEXTURE);
            model.renderToBuffer(poseStack, buffer.getBuffer(renderType), packedLight, packedOverlay, 1, 1, 1, 1);
            poseStack.method_22909();
        }
    }
}

==> touhoulittlemaid-fabric-1.21.1-0.2.0-neo1.4.2-sources.jar: com/github/tartaricacid/touhoulittlemaid/client/renderer/tileentity/PicnicBasketRender.java <==
package com.github.tartaricacid.touhoulittlemaid.client.renderer.tileentity;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.client.model.EntityPlaceholderModel;
import com.github.tartaricacid.touhoulittlemaid.client.model.bedrock.SimpleBedrockModel;
import com.github.tartaricacid.touhoulittlemaid.client.resource.BedrockModelLoader;
import net.minecraft.class_1297;
import net.minecraft.class_1799;
import net.minecraft.class_1921;
import net.minecraft.class_2960;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_5599;
import net.minecraft.class_756;
import net.minecraft.class_7833;
import net.minecraft.class_811;
import net.minecraft.class_824;

public class PicnicBasketRender extends class_756 {
    private static final class_2960 TEXTURE = class_2960.method_60655(TouhouLittleMaid.MOD_ID, "textures/bedrock/block/picnic_basket.png");
    private static final class_2960 GUI_TEXTURE = class_2960.method_60655(TouhouLittleMaid.MOD_ID, "textures/item/picnic_basket.png");
    private static final EntityPlaceholderModel GUI_MODEL = new EntityPlaceholderModel();
    private final SimpleBedrockModel<class_1297> model;

    public PicnicBasketRender(class_824 dispatcher, class_5599 modelSet) {
        super(dispatcher, modelSet);
        this.model = BedrockModelLoader.getModel(BedrockModelLoader.PICNIC_BASKET);
    }

    @Override
    public void method_3166(class_1799 pStack, class_811 displayContext, class_4587 poseStack, class_4597 buffer, int packedLight, int packedOverlay) {
        if (displayContext == class_811.field_4317) {
            poseStack.method_22903();
            poseStack.method_22904(0.5, 1.5, 0.5);
            poseStack.method_22907(class_7833.field_40717.rotationDegrees(180));
            GUI_MODEL.renderToBuffer(poseStack, buffer.getBuffer(class_1921.method_23578(GUI_TEXTURE)), packedLight, packedOverlay, 1.0F, 1.0F, 1.0F, 1.0F);
            poseStack.method_22909();
        } else if (model != null) {
            poseStack.method_22903();
            poseStack.method_22904(0.5, 1.5, 0.5);
            poseStack.method_22907(class_7833.field_40717.rotationDegrees(180));
            class_1921 renderType = class_1921.method_23578(TEXTURE);
            model.method_60879(poseStack, buffer.getBuffer(renderType), packedLight, packedOverlay);
            poseStack.method_22909();
        }
    }
}
